Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Root = &RootExpr{ HTTPEndpoints: map[string]map[string]*HTTPEndpointExpr{}, }
Root is the design root expression.
Functions ¶
This section is empty.
Types ¶
type HTTPEndpointExpr ¶
type HTTPEndpointExpr struct {
// MethodExpr is the underlying method expression.
MethodExpr *expr.MethodExpr
// Service is the parent service.
Service *expr.HTTPServiceExpr
// OptionalBody indicates that the HTTP request body is optional.
OptionalBody bool
}
HTTPEndpointExpr describes a HTTP endpoint.
func (*HTTPEndpointExpr) EvalName ¶
func (e *HTTPEndpointExpr) EvalName() string
EvalName returns the generic expression name used in error messages.
func (*HTTPEndpointExpr) Validate ¶
func (e *HTTPEndpointExpr) Validate() *eval.ValidationErrors
Validate validates the endpoint expression.
type RootExpr ¶
type RootExpr struct {
// HTTPEndpoints lists all the service endpoints indexed by service and method strings.
HTTPEndpoints map[string]map[string]*HTTPEndpointExpr
}
RootExpr keeps track of the optional bodies defined in the design.
Click to show internal directories.
Click to hide internal directories.